##  Role-Based Permissions
In SAP LeanIX, user permissions are based on their assigned roles. As an admin, you can configure permissions for non-admin user roles as needed. Permissions fall into two main categories:
  * Fact sheet permissions: Configure these in the Meta Model Configuration section of the administration area. For more details, see [Fact Sheet Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Configure fact sheet permissions for non-admin user roles.").
  * Permissions unrelated to fact sheets: Configure these in the User Roles and Permissions section of the administration area. For an overview of permissions, refer to the following table. Permissions for the admin role are read-only to ensure all workspace admins can view and modify items.


The table below lists permissions unrelated to fact sheets.
Feature | Permissions | Related Information
---|---|---
Architecture executive dashboard |
  * Read: View the architecture executive dashboard.
  * Update: Update the architecture executive dashboard.

| [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "The architecture executive dashboard provides essential KPIs related to the organization’s IT landscape, enabling informed, data-driven decision-making through valuable insights.")
KPIs |
  * Update: Update existing KPIs.
  * Create: Create new custom KPIs.
  * Delete: Delete custom KPIs.

| [KPIs](https://help.sap.com/docs/leanix/ea/kpis?locale=en-US&state=PRODUCTION&version=CLOUD "Configure KPIs and display them on dashboards to track enterprise architecture metrics.")
Portals | Open, delete, create, and update portals | [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.")
Collections | Manage collections and content within collections | [Collections](https://help.sap.com/docs/leanix/ea/collections?locale=en-US&state=PRODUCTION&version=CLOUD "Use collections to arrange dashboards, reports, and diagrams into custom groups.")
Surveys | Create and manage surveys | [Surveys](https://help.sap.com/docs/leanix/ea/creating-survey?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create surveys, from defining the scope and designing questions to using advanced fields and templates. Learn how to make questions mandatory, add links and descriptions, and import/export surveys.")
Fact sheet shape templates | Manage fact sheet shape templates in diagrams: view, delete, create, update, change the owner, change default settings, and unlock custom templates | [Fact Sheet Shape Templates](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates?locale=en-US&state=PRODUCTION&version=CLOUD "Create custom templates by assigning specific shapes and colors to fact sheets to match your organization's standards, or choose default standards like SAP LeanIX and Archimate 3.2 to visually represent fact sheets in diagrams.")
Presentations | Manage presentations | [Presentations](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD "Use presentations to share enterprise architecture insights from reports and diagrams with your organization, without the need to export data to external presentation tools.")
Discovery inbox | Access to the SAP landscape discovery inbox and SaaS discovery inbox | [SAP Landscape Discover Inbox](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically discover and inventory SAP systems, services, and integration flows, ensuring an up-to-date overview of your SAP landscape.") [SaaS Discovery Inbox](https://help.sap.com/docs/leanix/ea/saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SaaS discovery identifies your organization's SaaS applications by integrating with SSO, SASE, and CASB solutions. It then updates and enriches fact sheets using the reference catalog.")
Architecture decisions (available to customers using SAP LeanIX Architecture and Road Map Planning) |
  * View, create, update, and delete architecture decisions
  * Manage architecture decision templates

| [Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions?locale=en-US&state=PRODUCTION&version=CLOUD "Document and manage enterprise architecture decisions directly within SAP LeanIX, keeping all architecture-related information in one place.")
Software bill of materials (SBOM) |
  * Read: View SBOM explorer and SBOM fact sheet widget
  * Upload: Upload SBOM files

| [Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom?locale=en-US&state=PRODUCTION&version=CLOUD "To understand and manage dependencies among your microservices, generate SBOM files and ingest them into SAP LeanIX using our API.")
Tech stack discovery |
  * View tech stack discovery
  * Create and update tech stacks

| [Tech Stack Discovery from SBOMs](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically discover tech stacks from ingested SBOMs. Add custom tech stacks manually to complete your technology portfolio.")
Transformations | Read, create, update, delete, and execute transformations | [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.")
Developer tools |
  * Access the GraphQL editor.
  * Enable the Copy as JSON Query option in the filter bar in the inventory to copy the current query.

| [GraphQL API](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD "Get started with the SAP LeanIX GraphQL API.")


